# FastAAI

Author: Kenji Gerhardt
Email:  Kenji.Gerhardt@gmail.com
Author: Carlos Ruiz Perez
Email:  carlos.vernichtung@gmail.com

FastAAI uses tetramer frequency over shared universal sincle copy proteins to rapidly and accurately estimate average whole-genome amino acid identity.



